<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Zrakoplovni način rada omogućen</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Zrakoplovni način rada onemogućen</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished">Zrakoplovni način</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Zrakoplovni način</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth postavke</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished">Isključeno</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Uključi</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth postavke</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 povezan</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Povezujem...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Isključeno</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Ned</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Pon</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Uto</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Sri</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Čet</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Pet</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Sub</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Dodaj raspored tipkovnice</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datum vrijeme</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-satno vrijeme</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-satno vrijeme</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Postavke vremena</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Ponedjeljak</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Utorak</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Srijeda</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Četvrtak</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Petak</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Subota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Nedjelja</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>ponedjeljak</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>utorak</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>srijeda</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>četvrtak</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>petak</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>subota</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>nedjelja</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Energetske postavke</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Kapacitet %1, %2 min preostalo</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Kapacitet %1, %2 hr %3 min preostalo</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Punim %1, %2 min dok ne bude potpuno pun</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Punim %1, %2 hr %3 min dok ne bude potpuno pun</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapacitet %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Punjenje %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapacitet %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapacitet %1, potpuno napunjen</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Baterija</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation type="unfinished">Energetske postavke</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendiraj</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hiberniraj</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zaključaj</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energetske postavke</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovno podigni sustav</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished">Ponedjeljak</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished">Utorak</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished">Srijeda</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished">Četvrtak</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished">Petak</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished">Subota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished">Nedjelja</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>May</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jun</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jul</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Oct</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nov</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>monday</source>
        <translation type="unfinished">ponedjeljak</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation type="unfinished">utorak</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation type="unfinished">srijeda</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation type="unfinished">četvrtak</translation>
    </message>
    <message>
        <source>friday</source>
        <translation type="unfinished">petak</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation type="unfinished">subota</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation type="unfinished">nedjelja</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Glasnoća</translation>
    </message>
    <message>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
